summaryrefslogtreecommitdiff
path: root/gtk/dcerpc_stat.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
committerGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
commit92552c2d765dcf89883392fcd11556d54f2843e5 (patch)
treebb7476c5cd4845fce70a943d87cab8ddb12fe41d /gtk/dcerpc_stat.c
parent4c4664721edb7f9f7b9886a881d913e4dff2043a (diff)
downloadwireshark-92552c2d765dcf89883392fcd11556d54f2843e5.tar.gz
Get rid of a bunch of "Ethereal"s and "ethereal"s in comments, GUI
strings, and function names. svn path=/trunk/; revision=18205
Diffstat (limited to 'gtk/dcerpc_stat.c')
-rw-r--r--gtk/dcerpc_stat.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/dcerpc_stat.c b/gtk/dcerpc_stat.c
index 5c5c6ce0ac..e39883250a 100644
--- a/gtk/dcerpc_stat.c
+++ b/gtk/dcerpc_stat.c
@@ -22,9 +22,9 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply SRT statistics to ethereal,
* and displays them graphically.
* It is only used by ethereal and not tethereal
*
* It serves as an example on how to use the tap api.
*/
@@ -561,7 +561,7 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
return;
}
- dlg=dlg_window_new("Ethereal: Compute DCE-RPC SRT statistics");
+ dlg=dlg_window_new("Wireshark: Compute DCE-RPC SRT statistics");
gtk_window_set_default_size(GTK_WINDOW(dlg), 400, -1);
dlg_box=gtk_vbox_new(FALSE, 10);
@@ -22,9 +22,9 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply SRT statistics to ethereal,
+/* This module provides rpc call/reply SRT statistics to Wireshark,
* and displays them graphically.
@@ -22,9 +22,9 @@
* and displays them graphically.
- * It is only used by ethereal and not tethereal
+ * It is only used by Wireshark and not tethereal
*
* It serves as an example on how to use the tap api.